@@ -6,7 +6,5 @@ void tail()
     cout << "\n"
 "</tr>\n"
 "</table>\n"
-"</font>\n"
-"</body>\n"
-"</html>\n";
+"</body></html>\n";
 }
