@@ -29,7 +29,7 @@ class TypeTrait
         enum { isPointer = false };
         enum { isConst   = false };
 
-        typedef U Plain;
+        using Plain = U;
     };
 
     template <typename U> struct Type<U const>
@@ -37,10 +37,10 @@ class TypeTrait
         enum { isPointer = false };
         enum { isConst   = true };
 
-        typedef U Plain;
+        using Plain = U;
     };
 
-    typedef char small;
+    using small = char;
     struct Big {char big[2];};
 
     template <typename T2>
