@@ -13,7 +13,7 @@
     struct TypeAt<index, TypeList<>>
     {
         static_assert(index < 0, "TypeAt index out of bounds");
-        typedef TypeAt Type;
+        using Type = TypeAt;
     };
 //=
 
@@ -21,7 +21,7 @@
     template <typename Head, typename ...Tail>
     struct TypeAt<0, TypeList<Head, Tail...>>
     {
-        typedef Head Type;
+        using Type = Head;
     };
 //=
 
@@ -29,7 +29,7 @@
     template <size_t index, typename Head, typename ...Tail>
     struct TypeAt<index, TypeList<Head, Tail...>>
     {
-        typedef typename TypeAt<index - 1, TypeList<Tail...>>::Type Type;
+        using Type = typename TypeAt<index - 1, TypeList<Tail...>>::Type;
     };
 //=
 
