@@ -4,9 +4,9 @@
 
     class Daemon: public Fork
     {
-        virtual void parentProcess()        // the parent does nothing.
+        void parentProcess() override       // the parent does nothing.
         {}
-        virtual void childProcess()         // actions by the child
+        void childProcess() override        // actions by the child
         {
             sleep(3);
                                             // just a message...
