@@ -2,9 +2,9 @@
     #include "../fork.h"
     #include "../selector.h"
 
-       #include <sys/types.h>
-       #include <signal.h>
-       #include <sys/wait.h>
+    #include <sys/types.h>
+    #include <signal.h>
+    #include <sys/wait.h>
 
     #include <iostream>
 
@@ -20,16 +20,16 @@
 
         public:
             Child(int nr);
-            virtual ~Child();
+            ~Child() override;
             int readFd() const;
             int writeFd() const;
             int pid() const;
             int nr() const;
         private:
-            virtual void childRedirections();
-            virtual void parentRedirections();
-            virtual void childProcess();
-            virtual void parentProcess();
+            void childRedirections() override;
+            void parentRedirections() override;
+            void childProcess() override;
+            void parentProcess() override;
     };
 //=
 
