@@ -16,8 +16,8 @@ class Promise: public PromiseBase
     std::remove_reference_t<T> *d_valuePtr;
 
     public:
-        typedef std::remove_reference_t<T> Value;
-        typedef std::conditional_t<std::is_reference_v<T>, T, T&> Reference;
+        using Value = std::remove_reference_t<T>;
+        using Reference = std::conditional_t<std::is_reference_v<T>, T, T&>;
 
         Generator<T> get_return_object() noexcept;
 
