@@ -9,10 +9,6 @@
         cout << "more than 5: " << exchange(more, argc > 2) <<
                 ", more than 2: " << more << '\n';
     }
-    /*
-        Using g++ at least version 7.0.0:
-        With `a.out one two three' displays:
-
-        more than 5: 0, more than 2: 1
-
-    */
+    //  With `a.out one two three' displays:
+    //
+    //  more than 5: 0, more than 2: 1
