@@ -25,5 +25,13 @@
 
         copy(uv.begin(), uv.end(), ostream_iterator<int>{ cout, " " });
         cout << '\n';
+
+        uv = vector<size_t>(10);
+        generate_n(uv.begin(), 5, NaturalSquares{});
+
+        copy(uv.begin(), uv.end(), ostream_iterator<int>{ cout, " " });
+        cout << '\n';
+
     }
     // Displays:   1 4 9 16 25 36 49 64 81 100
+    //             1 4 9 16 25 0 0 0 0 0
