@@ -7,6 +7,7 @@
         operator int() const
         {
             cout << "op int()\n";
+            return 0;
         }
     };
     ostream &operator<<(ostream &out, Insertable const &ins)
@@ -31,7 +32,7 @@
     {
         operator Text() const
         {
-            return Text();
+            return Text{};
         }
     };
 
