@@ -6,7 +6,7 @@
     {}
     class Derived: public Base
     {
-        virtual void member();      // only declared
+        void member() override;      // only declared
     };
     int main()
     {
