@@ -16,11 +16,13 @@
             Time(size_t hours, size_t minutes, size_t seconds);
             Time &operator+=(Time const &rhs);
     };
-    Time &&operator+(Time const &lhs, Time const &rhs)
+
+    Time operator+(Time const &lhs, Time const &rhs)
     {
         Time ret(lhs);
-        return std::move(ret += rhs);
+        return ret += rhs;
     }
+
     Time::Time(size_t hours, size_t minutes, size_t seconds)
     :
         d_days(0),
