@@ -2,7 +2,7 @@
 #include <iostream>
 using namespace std;
 
-typedef shared_ptr<int> si;
+using si = shared_ptr<int>;
 int main()
 {
     si ip(new int(12));
