@@ -6,7 +6,7 @@
 
 class Semaphore
 {
-    mutable std::mutex d_mutex;
+    std::mutex d_mutex;
     std::condition_variable d_condition;
     size_t d_nAvailable;
 
